@@ -71,6 +71,7 @@ void settings_callback(GObject *widget, gpointer user_data);
 void quit_callback(GObject *widget, gpointer user_data);
 void browse_callback(GObject *widget, gpointer user_data);
 void bluetooth_status_callback (GObject *widget, gpointer user_data);
+void bluetooth_discoverable_callback (GtkToggleAction *toggleaction, gpointer user_data);
 void wizard_callback(GObject *widget, gpointer user_data);
 void sendto_callback(GObject *widget, gpointer user_data);
 
@@ -106,14 +107,14 @@ void browse_callback(GObject *widget, gpointer user_data)
 
 	address = g_strdup (g_object_get_data (widget, "address"));
 	if (address == NULL) {
-		GtkWidget *dialog, *selector, *button;
+		GtkWidget *dialog, *selector;
 		int response_id;
 
 		dialog = gtk_dialog_new_with_buttons(_("Select Device to Browse"), NULL,
 						     GTK_DIALOG_NO_SEPARATOR,
 						     GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT,
 						     NULL);
-		button = gtk_dialog_add_button (GTK_DIALOG (dialog), _("_Browse"), GTK_RESPONSE_ACCEPT);
+		gtk_dialog_add_button (GTK_DIALOG (dialog), _("_Browse"), GTK_RESPONSE_ACCEPT);
 		gtk_dialog_set_response_sensitive(GTK_DIALOG(dialog),
 						  GTK_RESPONSE_ACCEPT, FALSE);
 		gtk_window_set_default_size(GTK_WINDOW(dialog), 480, 400);
@@ -231,6 +232,15 @@ void bluetooth_status_callback (GObject *widget, gpointer user_data)
 	g_object_set_data (object, "bt-active", GINT_TO_POINTER (active));
 }
 
+void
+bluetooth_discoverable_callback (GtkToggleAction *toggleaction, gpointer user_data)
+{
+	gboolean discoverable;
+
+	discoverable = gtk_toggle_action_get_active (toggleaction);
+	bluetooth_client_set_discoverable (client, discoverable);
+}
+
 static gboolean program_available(const char *program)
 {
 	gchar *path;
@@ -274,6 +284,12 @@ killswitch_state_changed (BluetoothKillswitch *killswitch, KillswitchState state
 	gboolean bstate = FALSE;
 	const char *label, *status_label;
 
+	if (state == KILLSWITCH_STATE_NO_ADAPTER) {
+		object = gtk_builder_get_object (xml, "bluetooth-applet-popup");
+		gtk_menu_popdown (GTK_MENU (object));
+		return;
+	}
+
 	if (state == KILLSWITCH_STATE_SOFT_BLOCKED) {
 		label = N_("Turn On Bluetooth");
 		status_label = N_("Bluetooth: Off");
@@ -292,6 +308,7 @@ killswitch_state_changed (BluetoothKillswitch *killswitch, KillswitchState state
 
 	object = gtk_builder_get_object (xml, "killswitch-label");
 	gtk_action_set_label (GTK_ACTION (object), _(status_label));
+	gtk_action_set_visible (GTK_ACTION (object), TRUE);
 
 	object = gtk_builder_get_object (xml, "killswitch");
 	gtk_action_set_visible (GTK_ACTION (object), sensitive);
@@ -329,12 +346,13 @@ static GtkWidget *create_popupmenu(void)
 
 	gtk_builder_connect_signals (xml, NULL);
 
-	if (killswitch != NULL) {
+	if (bluetooth_killswitch_has_killswitches (killswitch) != FALSE) {
 		GObject *object;
 
 		object = gtk_builder_get_object (xml, "killswitch-label");
 		gtk_action_set_visible (GTK_ACTION (object), TRUE);
 	}
+
 	if (option_debug != FALSE) {
 		GObject *object;
 
@@ -387,7 +405,8 @@ update_icon_visibility (void)
 		set_icon (TRUE);
 
 	if (show_icon_pref != FALSE) {
-		if (num_adapters_present > 0 || killswitch != NULL) {
+		if (num_adapters_present > 0 ||
+		    bluetooth_killswitch_has_killswitches (killswitch) != FALSE) {
 			show_icon ();
 			return;
 		}
@@ -395,6 +414,27 @@ update_icon_visibility (void)
 	hide_icon ();
 }
 
+static void
+update_discoverability (GtkTreeIter *iter)
+{
+	gboolean discoverable;
+	GObject *object;
+
+	object = gtk_builder_get_object (xml, "discoverable");
+
+	if (iter == NULL) {
+		gtk_action_set_visible (GTK_ACTION (object), FALSE);
+		return;
+	}
+
+	gtk_tree_model_get (devices_model, iter,
+			    BLUETOOTH_COLUMN_DISCOVERABLE, &discoverable,
+			    -1);
+
+	gtk_action_set_visible (GTK_ACTION (object), TRUE);
+	gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (object), discoverable);
+}
+
 static void
 set_device_status_label (const char *address, int connected)
 {
@@ -723,8 +763,9 @@ update_device_list (GtkTreeIter *parent)
 
 			list = g_hash_table_get_values (services);
 			for (l = list; l != NULL; l = l->next) {
-				gboolean val = GPOINTER_TO_INT (l->data);
-				if (val != FALSE) {
+				BluetoothStatus val = GPOINTER_TO_INT (l->data);
+				if (val == BLUETOOTH_STATUS_CONNECTED ||
+				    val == BLUETOOTH_STATUS_PLAYING) {
 					is_connected = TRUE;
 					break;
 				}
@@ -899,6 +940,7 @@ static void device_changed (GtkTreeModel *model,
 		cont = gtk_tree_model_iter_next (model, &iter);
 	}
 
+	update_discoverability (default_iter);
 	update_icon_visibility ();
 	update_menu_items ();
 	update_device_list (default_iter);
@@ -973,6 +1015,7 @@ int main(int argc, char *argv[])
 	if (option_debug == FALSE) {
 		app = unique_app_new ("org.gnome.Bluetooth.applet", NULL);
 		if (unique_app_is_running (app)) {
+			gdk_notify_startup_complete ();
 			g_warning ("Applet is already running, exiting");
 			return 0;
 		}
@@ -985,13 +1028,8 @@ int main(int argc, char *argv[])
 	gtk_window_set_default_icon_name("bluetooth");
 
 	killswitch = bluetooth_killswitch_new ();
-	if (bluetooth_killswitch_has_killswitches (killswitch) == FALSE) {
-		g_object_unref (killswitch);
-		killswitch = NULL;
-	} else {
-		g_signal_connect (G_OBJECT (killswitch), "state-changed",
-				  G_CALLBACK (killswitch_state_changed), NULL);
-	}
+	g_signal_connect (G_OBJECT (killswitch), "state-changed",
+			  G_CALLBACK (killswitch_state_changed), NULL);
 
 	menu = create_popupmenu();
 
@@ -1007,7 +1045,7 @@ int main(int argc, char *argv[])
 			  G_CALLBACK (device_changed), NULL);
 	/* Set the default */
 	device_changed (devices_model, NULL, NULL, NULL);
-	if (killswitch != NULL) {
+	if (bluetooth_killswitch_has_killswitches (killswitch) != FALSE) {
 		killswitch_state_changed (killswitch,
 					  bluetooth_killswitch_get_state (killswitch));
 	}
