@@ -144,11 +144,12 @@ void hide_icon(void)
 
 void set_icon(gboolean enabled)
 {
-	const char *name = (enabled ? "bluetooth" : "bluetooth-disabled");
+	const char *name = (enabled ? "bluetooth-active" : "bluetooth-disabled");
 	const char *_tooltip = enabled ? _("Bluetooth: Enabled") : _("Bluetooth: Disabled");
 
 	if (statusicon == NULL) {
 		g_free (icon_name);
+		g_free (tooltip);
 		icon_name = g_strdup (name);
 		tooltip = g_strdup (_tooltip);
 	} else {
