@@ -210,6 +210,7 @@ bluetooth_chooser_button_clicked (GtkButton *widget)
 	g_signal_emit (G_OBJECT (button),
 		       signals[CHOOSER_CREATED],
 		       0, button->chooser);
+	g_object_set (G_OBJECT (button->chooser), "device-selected", button->bdaddr, NULL);
 	gtk_container_set_border_width (GTK_CONTAINER(button->chooser), 5);
 	gtk_widget_show (button->chooser);
 	gtk_container_add (GTK_CONTAINER (gtk_dialog_get_content_area (GTK_DIALOG (button->dialog))), button->chooser);
@@ -315,15 +316,13 @@ bluetooth_chooser_button_class_init (BluetoothChooserButtonClass *klass)
 	button_class->clicked = bluetooth_chooser_button_clicked;
 
 	/**
-	 * BluetoothChooserButton:chooser-created:
-	 *
-	 * @bluetoothchooserbutton: a #BluetoothChooserButton widget
-	 * @arg1: a #BluetoothChooser widget
+	 * BluetoothChooserButton::chooser-created:
+	 * @self: a #BluetoothChooserButton widget
+	 * @chooser: a #BluetoothChooser widget
 	 *
 	 * The signal is sent when a popup dialogue is created for the user to select
 	 * a device. This signal allows you to change the configuration and filtering
 	 * of the tree from its defaults.
-	 *
 	 **/
 	signals[CHOOSER_CREATED] =
 		g_signal_new ("chooser-created",
