@@ -37,6 +37,8 @@ DBusGProxy *bluetooth_client_get_default_adapter(BluetoothClient *client);
 
 gboolean bluetooth_client_start_discovery(BluetoothClient *client);
 gboolean bluetooth_client_stop_discovery(BluetoothClient *client);
+gboolean bluetooth_client_set_discoverable (BluetoothClient *client,
+					    gboolean discoverable);
 
 typedef void (*BluetoothClientCreateDeviceFunc) (BluetoothClient *client,
 						 const char *path,
@@ -63,6 +65,10 @@ gboolean bluetooth_client_disconnect_service (BluetoothClient *client,
 					      BluetoothClientConnectFunc func,
 					      gpointer data);
 
+void bluetooth_client_dump_device (GtkTreeModel *model,
+				   GtkTreeIter *iter,
+				   gboolean recurse);
+
 G_END_DECLS
 
 #endif /* __BLUETOOTH_CLIENT_PRIVATE_H */
